@@ -1,5 +1,5 @@
 ;;; -*- Mode: LISP; Syntax: COMMON-LISP; Package: CL-PPCRE; Base: 10 -*-
-;;; $Header: /usr/local/cvsrep/cl-ppcre/api.lisp,v 1.72 2007/03/24 23:52:44 edi Exp $
+;;; $Header: /usr/local/cvsrep/cl-ppcre/api.lisp,v 1.75 2007/09/13 07:52:13 edi Exp $
 
 ;;; The external API for creating and using scanners.
 
@@ -156,7 +156,7 @@ argument \(but only if it's a parse tree)."))
                                       (regex-min-length regex)
                                       (or (start-anchored-p regex)
                                           ;; a dot in single-line-mode also
-                                          ;; implicitely anchors the regex at
+                                          ;; implicitly anchors the regex at
                                           ;; the start, i.e. if we can't match
                                           ;; from the first position we won't
                                           ;; match at all
@@ -961,7 +961,8 @@ representing the corresponding register start and end positions."
                             (element-type #+:lispworks 'lw:simple-char #-:lispworks 'character))
   (declare #.*standard-optimize-settings*)
   "Try to match TARGET-STRING between START and END against REGEX and
-replace the first match with REPLACEMENT.
+replace the first match with REPLACEMENT.  Two values are returned;
+the modified string, and T if REGEX matched or NIL otherwise.
 
   REPLACEMENT can be a string which may contain the special substrings
 \"\\&\" for the whole match, \"\\`\" for the part of TARGET-STRING
@@ -991,12 +992,14 @@ match.
   (multiple-value-bind (match-start match-end reg-starts reg-ends)
       (scan regex target-string :start start :end end)
     (if match-start
-      (replace-aux target-string replacement
+      (values (replace-aux target-string replacement
                    (list match-start match-end)
                    (list reg-starts reg-ends)
                    start end preserve-case
                    simple-calls element-type)
-      (subseq target-string start end))))
+              t)
+      (values (subseq target-string start end)
+              nil))))
 
 #-:cormanlisp
 (define-compiler-macro regex-replace
@@ -1015,7 +1018,8 @@ match.
                                      (element-type #+:lispworks 'lw:simple-char #-:lispworks 'character))
   (declare #.*standard-optimize-settings*)
   "Try to match TARGET-STRING between START and END against REGEX and
-replace all matches with REPLACEMENT.
+replace all matches with REPLACEMENT.  Two values are returned; the
+modified string, and T if REGEX matched or NIL otherwise.
 
   REPLACEMENT can be a string which may contain the special substrings
 \"\\&\" for the whole match, \"\\`\" for the part of TARGET-STRING
@@ -1052,12 +1056,14 @@ match.
       (push reg-starts reg-list)
       (push reg-ends reg-list))
     (if pos-list
-      (replace-aux target-string replacement
+      (values (replace-aux target-string replacement
                    (nreverse pos-list)
                    (nreverse reg-list)
                    start end preserve-case
                    simple-calls element-type)
-      (subseq target-string start end))))
+              t)
+      (values (subseq target-string start end)
+              nil))))
 
 #-:cormanlisp
 (define-compiler-macro regex-replace-all
