@@ -1,10 +1,10 @@
 ;;; -*- Mode: LISP; Syntax: COMMON-LISP; Package: CL-PPCRE; Base: 10 -*-
-;;; $Header: /usr/local/cvsrep/cl-ppcre/closures.lisp,v 1.32 2006/10/11 15:41:42 edi Exp $
+;;; $Header: /usr/local/cvsrep/cl-ppcre/closures.lisp,v 1.34 2007/01/15 23:57:41 edi Exp $
 
 ;;; Here we create the closures which together build the final
 ;;; scanner.
 
-;;; Copyright (c) 2002-2006, Dr. Edmund Weitz. All rights reserved.
+;;; Copyright (c) 2002-2007, Dr. Edmund Weitz. All rights reserved.
 
 ;;; Redistribution and use in source and binary forms, with or without
 ;;; modification, are permitted provided that the following conditions
@@ -155,14 +155,14 @@ such that the call to NEXT-FN after the match would succeed."))
       ;; far enough from the start of *STRING*), then call NEXT-FN
       (lambda (start-pos)
         (declare (type fixnum start-pos))
-        (and (>= (- start-pos *start-pos*) len)
+        (and (>= (- start-pos (or *real-start-pos* *start-pos*)) len)
              (funcall test-matcher (- start-pos len))
              (funcall next-fn start-pos)))
       ;; negative look-behind: check failure of inner regex (if we're
       ;; far enough from the start of *STRING*), then call NEXT-FN
       (lambda (start-pos)
         (declare (type fixnum start-pos))
-        (and (or (< start-pos len)
+        (and (or (< (- start-pos (or *real-start-pos* *start-pos*)) len)
                  (not (funcall test-matcher (- start-pos len))))
              (funcall next-fn start-pos))))))
 
