@@ -1,9 +1,9 @@
 ;;; -*- Mode: LISP; Syntax: COMMON-LISP; Package: CL-PPCRE; Base: 10 -*-
-;;; $Header: /usr/local/cvsrep/cl-ppcre/specials.lisp,v 1.23 2006/08/10 14:45:24 edi Exp $
+;;; $Header: /usr/local/cvsrep/cl-ppcre/specials.lisp,v 1.25 2007/03/24 23:52:45 edi Exp $
 
 ;;; globally declared special variables
 
-;;; Copyright (c) 2002-2006, Dr. Edmund Weitz. All rights reserved.
+;;; Copyright (c) 2002-2007, Dr. Edmund Weitz. All rights reserved.
 
 ;;; Redistribution and use in source and binary forms, with or without
 ;;; modification, are permitted provided that the following conditions
@@ -120,6 +120,10 @@ but large) Boyer-Moore-Horspool matchers.")
 (defvar *allow-quoting* nil
   "Whether the parser should support Perl's \\Q and \\E.")
 
+(defvar *allow-named-registers* nil
+  "Whether the parser should support AllegroCL's named registers
+\(?<name>\"<regex>\") and back-reference \\k<name> syntax.")
+
 (pushnew :cl-ppcre *features*)
 
 ;; stuff for Nikodemus Siivola's HYPERDOC
